class InitialScheme < ActiveRecord::Migration

  def self.up

    create_table "directories", :force => true do |t|
      t.column "parent_id", :integer
      t.column "name", :string, :default => "", :null => false
      t.column "path", :string, :default => "", :null => false
      t.column "plain_file", :boolean, :default => false, :null => false
    end

    create_table "variables", :force => true do |t|
      t.column "directory_id", :integer, :default => 0, :null => false
      t.column "name", :string, :default => "", :null => false
      t.column "path", :string, :default => "", :null => false
      t.column "gphysizable", :boolean, :default => true, :null => false
      t.column "user_id", :integer
      t.column "group_id", :integer
      t.column "starttime", :datetime
      t.column "endtime", :datetime
    end

    create_table "actual_files", :force => true do |t|
      t.column "variable_id", :integer, :null => false
      t.column "path", :string, :null => false
    end

    create_table "variable_relations", :force => true do |t|
      t.column "reference", :integer, :null => false
      t.column "cited_by", :integer, :null => false
    end

    create_table "keyword_attributes", :force => true do |t|
      t.column "variable_id", :integer
      t.column "directory_id", :integer
      t.column "name", :string, :default => "", :null => false
      t.column "value", :text
      t.column "num_value", :binary
      t.column "lang", :string
    end

    create_table "spatial_attributes", :force => true do |t|
      t.column "variable_id", :integer
      t.column "directory_id", :integer
      t.column "longitude_lb", :float, :default => nil 
      t.column "latitude_lb", :float, :default => nil
      t.column "longitude_rt", :float, :default => nil
      t.column "latitude_rt", :float, :default => nil
      t.column "lon_ax_name", :string, :default => nil
      t.column "lat_ax_name", :string, :default => nil
    end

    create_table "functions", :force => true do |t|
      t.column "name", :string, :null => false
      t.column "description", :text
      t.column "input_num", :integer, :null => false
      t.column "script", :text, :null => false
      t.column "user_id", :integer
      t.column "group_id", :integer
    end

    create_table "function_outputs", :force => true do |t|
      t.column "function_id", :integer, :null => false
      t.column "name", :string, :null => false
      t.column "description", :text
      t.column "subscript", :string, :null => false
      t.column "position", :integer, :null => false
    end

    create_table "types", :force => true do |t|
      t.column "name", :string, :null => false
    end

    create_table "function_arguments", :force => true do |t|
      t.column "function_id", :integer, :null => false
      t.column "description", :text
      t.column "type_id", :integer, :null => false
      t.column "default", :string
      t.column "position", :integer, :null => false
    end

    create_table "users", :force => true do |t|
      t.column "login", :string, :null => false
      t.column "password", :string, :null => false
      t.column "full_name", :string, :null => false
      t.column "email_address", :string, :null => false
      t.column "affiliation", :string, :null => false
      t.column "super_user", :boolean, :default => false, :null => false
    end

    create_table "sign_up_users", :force => true do |t|
      t.column "login", :string, :null => false
      t.column "password", :string, :null => false
      t.column "full_name", :string, :null => false
      t.column "email_address", :string, :null => false
      t.column "affiliation", :string, :null => false
    end

    create_table "groups", :force => true do |t|
      t.column "name", :string, :null => false
      t.column "user_id", :integer, :null => false
    end

    create_table "group_members", :force => true do |t|
      t.column "user_id", :integer, :null => false
      t.column "group_id", :integer, :null => false
    end

    create_table "diagram_caches", :force => true do |t|
      t.column "uri_params", :text, :null => false
      t.column "path", :string, :null => false
      t.column "label", :string, :null => false
    end

    create_table "diagram_cache_data", :force => true do |t|
      t.column "diagram_cache_id", :integer, :null => false
      t.column "variable_id", :integer, :null => false
    end

    create_table "diagram_cache_sessions", :force => true do |t|
      t.column "diagram_cache_id", :integer, :null => false
      t.column "session", :string, :null => false
      t.column "share", :boolean, :default => true, :null => false
    end

  end

  def self.down

    drop_table :spatial_attributes
    drop_table :keyword_attributes
    drop_table :variable_relations
    drop_table :variables
    drop_table :directories

    drop_table :function_arguments
    drop_table :types
    drop_table :function_outputs
    drop_table :functions

    drop_table :group_members
    drop_table :groups
    drop_table :users

    drop_table :diagram_cache_sessions
    drop_table :diagram_cache_data
    drop_table :diagram_caches
    
    drop_table :query_histories
  end
end
